package main

import "fmt"
import "strconv"
import "math/rand"

type carta struct {
	seme int   // 0=picche, 1=fiori, 2=quadri, 3=cuori
	val int    // 0=2, 1=3, 2=4, 3=5, 4=6, 5=7, 6=8, 7=9, 8=10, 9=J, 10=Q, 11=K, 12=A
}

func carta2string(c carta) string {
	var res string 
	switch c.val {
	case 9: 
		res = " J"
	case 10: 
		res = " Q"
	case 11: 
		res = " K"
	case 12: 
		res = " A"
	default:
		res = fmt.Sprintf("%2d", c.val + 2)
	}
	switch c.seme {
	case 0:
		res += "♠️"
	case 1:
		res += "♣️"
	case 2:
		res += "♦️"
	case 3:
		res += "❤️"
	}
	return res
}

/* Restituisce un mazzo contenente tutte le carte */
func mazzo() []carta {
	var res []carta

	for seme := 0; seme < 4; seme++ {
		for valore := 0; valore < 13; valore++ {
			res = append(res, carta{seme, valore})
		}
	}
	return res
}

/* Mescola la slice m. */
func mescolaMazzo(m []carta) {
	for i := range m {
		j := i + rand.Intn(len(m) - i)   // Genera un numero a caso fra i, i+1, i+2, ..., len(m)-1 
		m[i], m[j] = m[j], m[i]
	}
}


func main() {
	m := mazzo()
	mescolaMazzo(m)

	var mano [5]carta

	for i:=0; i<5; i++ {
		mano[i] = m[i]
	}


	for i, c := range mano {
		fmt.Printf("%d. %s\n", i, carta2string(c))
	}

	n := 5   // Numero di carte già prese dal mazzo
 
	var daCambiare string
	fmt.Scan(&daCambiare)

	for i := 0; i < len(daCambiare); i++ {
		j, _ := strconv.Atoi(daCambiare[i:i+1])   // Indice di una carta da cambiare
		mano[j] = m[n]
		n++
	}

	for i, c := range mano {
		fmt.Printf("%d. %s\n", i, carta2string(c))
	}

}



